Gilda modules reference
=======================

API
---

.. automodule:: gilda.api
    :members:
    :show-inheritance:

Grounder
--------

.. automodule:: gilda.grounder
    :members:
    :show-inheritance:

Scorer
------

.. automodule:: gilda.scorer
    :members:
    :show-inheritance:

Term
----

.. automodule:: gilda.term
    :members:
    :show-inheritance:

Process
-------

.. automodule:: gilda.process
    :members:
    :show-inheritance:

Named Entity Recognition
------------------------
.. automodule:: gilda.ner
    :members:
    :show-inheritance:


Pandas Utilities
----------------
.. automodule:: gilda.pandas_utils
    :members:
    :show-inheritance:
